/* ti397.h: Routines for handling the FDD3000 interface
   (based on the +D routines)

   Copyright (c) 1999-2016 Stuart Brady, Fredrick Meunier, Philip Kendall,
   Dmitry Sanarin, Darren Salt, 2014 Gergely Szasz, Sławomir Szczyrba

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

   Author contact information:

   Philip: philip-fuse@shadowmagic.org.uk

   Stuart: stuart.brady@gmail.com

*/

#ifndef TI397_H
#define TI397_H

typedef enum fdd3000_drive_number {
  FDD3000_DRIVE_A = 0,
  FDD3000_DRIVE_B,
  FDD3000_DRIVE_C,
  FDD3000_DRIVE_D,
  FDD3000_NUM_DRIVES,
} fdd3000_drive_number;

#include <libspectrum.h>

#include "fdd.h"
#include "wd_fdc.h"

extern int fdd3000_available;  /* Is the FDD3000 available for use? */
extern int fdd3000_active;     /* FDD3000 enabled? */

void fdd3000_register_startup( void );

void fdd3000_page( void );
void fdd3000_unpage( void );

int fdd3000_disk_insert( fdd3000_drive_number which, const char *filename,
                         int autoload );
int fdd3000_disk_eject( fdd3000_drive_number which );
int fdd3000_disk_save(  fdd3000_drive_number which, int saveas );
int fdd3000_disk_write( fdd3000_drive_number which, const char *filename );
int fdd3000_disk_flip(  fdd3000_drive_number which, int flip );
int fdd3000_disk_writeprotect( fdd3000_drive_number which, int wrprot );
fdd_t *fdd3000_get_fdd( fdd3000_drive_number which );

int fdd3000_unittest( void );

void    wrCommandReg( uint8_t val );
void    wrTrackReg( uint8_t val );
void    wrSectorReg( uint8_t val );
void    wrDataReg( uint8_t val );

uint8_t rdStatusReg( void );
uint8_t rdTrackReg( void );
uint8_t rdSectorReg( void );
uint8_t rdDataReg( void );

void    setDriveCfg( uint8_t val );

extern wd_fdc *fdd3000_fdc;

#endif                  /* #ifndef TI397_H */
